from dataclasses import dataclass


@dataclass
class FriendRequestMessage:
    def __init__(self, sender_name: str, receiver_name: str):
        self.sender_name = sender_name
        self.receiver_name = receiver_name


@dataclass
class FriendAcceptanceMessage:
    def __init__(self, user_name: str, friend_name: str):
        self.user_name = user_name
        self.friend_name = friend_name


@dataclass
class StatusMessage:
    def __init__(self, username: str, status_text: str, event: str):
        self.username = username
        self.status_text = status_text
        self.event = event



import pika
from fastapi import Request
from motor.motor_asyncio import AsyncIOMotorClient
from tenacity import retry, stop_after_attempt, wait_exponential


def get_current_username(request: Request):
    return request.session.get("user")


async def get_mongo_db(DATABASE_URL: str):
    client = AsyncIOMotorClient(DATABASE_URL)
    db = client.get_default_database()
    try:
        yield db
    finally:
        client.close()


class BaseRabbit:
    def __init__(self, RABBITMQ_HOST: str):
        self.connection = pika.BlockingConnection(pika.URLParameters(RABBITMQ_HOST))
        self.channel = self.connection.channel()

    def close_connection(self):
        self.connection.close()

    # TODO The below two functions should be more flexible to
    # allow for different queue declaration parameters in the future
    @retry(
        stop=stop_after_attempt(5), wait=wait_exponential(multiplier=1, min=1, max=10)
    )
    def publish(self, exchange, queue, message, declare_queue=True):
        if declare_queue:
            self.channel.queue_declare(queue=queue, durable=True)
        self.channel.basic_publish(exchange=exchange, routing_key=queue, body=message)

    def start_consuming(self, queue, callback, declare_queue=True, auto_ack=True):
        if declare_queue:
            self.channel.queue_declare(queue=queue, durable=True)
        self.channel.basic_consume(
            queue=queue, on_message_callback=callback, auto_ack=auto_ack
        )
        self.channel.start_consuming()

    def stop_consuming(self):
        if self.channel.is_open:
            self.channel.stop_consuming()



from setuptools import setup, find_packages

setup(
    name="wheelio_ashwin",
    version="0.0.2",
    packages=find_packages(),
    install_requires=[
        "pyjwt",
        "fastapi",
        "motor",
        "tenacity",
        "starlette_authlib",
        "pika",
    ],
    author="Ashwin Singh",
    author_email="ashwinsinghgr8@gmail.com",
    description="A common package for shared utilities and models for wheel.io technical challenge",
    long_description="Do not use this, this will go off in some time",
    long_description_content_type="text/markdown",
    url="https://github.com/yourusername/common_package",
    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
    ],
    python_requires=">=3.11",
)
